Module complex

Module complex 

Native complex number type. Native complex number type for generic tensor operations.

Provides Complex<T> which implements Scalar so it can be used directly as a tensor element type: Tensor<Complex<f64>>.

Structs

Complex
A complex number with real and imaginary parts of type T.

Functions

from_interleaved
Convert interleaved real data [re0, im0, re1, im1, ...] to a Vec<Complex<T>>.
to_interleaved
Convert a slice of Complex<T> to interleaved real data [re0, im0, re1, im1, ...].