CoreError

Enum CoreError 

#[non_exhaustive]
pub enum CoreError { DimensionMismatch { expected: Vec<usize>, got: Vec<usize>, }, InvalidShape { shape: Vec<usize>, reason: &'static str, }, AxisOutOfBounds { axis: usize, ndim: usize, }, IndexOutOfBounds { index: Vec<usize>, shape: Vec<usize>, }, SingularMatrix, InvalidArgument { reason: &'static str, }, BroadcastError { shape_a: Vec<usize>, shape_b: Vec<usize>, }, }
All errors returned by scivex-core.

Examples

use scivex_core::error::CoreError;
let e = CoreError::SingularMatrix;
assert_eq!(format!("{e}"), "singular matrix");

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DimensionMismatch

Operand shapes do not match the required layout.

Fields

expected: Vec<usize>
got: Vec<usize>


InvalidShape

A shape or stride specification is invalid.

Fields

shape: Vec<usize>
reason: &'static str


AxisOutOfBounds

An axis index is out of bounds for the tensor’s rank.

Fields

axis: usize
ndim: usize


IndexOutOfBounds

A flat or multi-dimensional index is out of bounds.

Fields

index: Vec<usize>
shape: Vec<usize>


SingularMatrix

Matrix is singular and cannot be inverted / decomposed.



InvalidArgument

The operation is not supported for the given input.

Fields

reason: &'static str


BroadcastError

Shapes cannot be broadcast together.

Fields

shape_a: Vec<usize>
shape_b: Vec<usize>