pub struct PathInfo {
pub path: Vec<ContractionPair>,
pub flops: usize,
pub largest_intermediate: usize,
}Expand description
Information about the chosen contraction path.
Fields
path: Vec<ContractionPair>Sequence of pairwise contractions. Each pair refers to indices in the operand list at that step (operands are removed and the intermediate result is appended after each step).
flops: usizeEstimated total number of multiply-add operations (FLOPs).
largest_intermediate: usizeSize of the largest intermediate tensor (in number of elements).