Complex

Struct Complex 

pub struct Complex<T> {
    pub re: T,
    pub im: T,
}
A complex number with real and imaginary parts of type T.

Examples

let z = Complex::new(3.0_f64, 4.0);
assert_eq!(z.norm(), 5.0);

Fields

re: T

Real part.

im: T

Imaginary part.

Implementations

Source

impl<T: Float> Complex<T>

pub fn new(re: T, im: T) -> Self

Create a new complex number from real and imaginary parts.

Examples
let z = Complex::new(1.0_f64, 2.0);
assert_eq!(z.re, 1.0);
assert_eq!(z.im, 2.0);
pub fn from_real(re: T) -> Self

Create a complex number from a real value (imaginary part is zero).

Examples
let z = Complex::from_real(3.0_f64);
assert_eq!(z.im, 0.0);
pub fn from_polar(r: T, theta: T) -> Self

Create a complex number from polar form: r * (cos(theta) + i*sin(theta)).

Examples
let z = Complex::from_polar(1.0_f64, 0.0_f64);
assert!((z.re - 1.0).abs() < 1e-15);
assert!(z.im.abs() < 1e-15);
pub fn conj(self) -> Self

Complex conjugate: flips the sign of the imaginary part.

Examples
let z = Complex::new(3.0_f64, 4.0);
let c = z.conj();
assert_eq!(c.re, 3.0);
assert_eq!(c.im, -4.0);
pub fn norm_sqr(self) -> T

Squared modulus: re² + im². Avoids the sqrt in norm.

Examples
let z = Complex::new(3.0_f64, 4.0);
assert_eq!(z.norm_sqr(), 25.0);
pub fn norm(self) -> T

Modulus (absolute value): sqrt(re² + im²).

pub fn arg(self) -> T

Phase angle (argument): atan2(im, re).

Examples
let z = Complex::new(0.0_f64, 1.0); // i
let angle = z.arg();
assert!((angle - std::f64::consts::FRAC_PI_2).abs() < 1e-10);
pub fn exp(self) -> Self

Complex exponential: e^(a+bi) = e^a * (cos b + i sin b).

Examples
// e^0 = 1
let z = Complex::new(0.0_f64, 0.0);
let e = z.exp();
assert!((e.re - 1.0).abs() < 1e-15);
assert!(e.im.abs() < 1e-15);
pub fn ln(self) -> Self

Complex natural logarithm: ln|z| + i*arg(z).

Examples
// ln(1) = 0
let z = Complex::new(1.0_f64, 0.0);
let l = z.ln();
assert!(l.re.abs() < 1e-15);
assert!(l.im.abs() < 1e-15);
pub fn sqrt(self) -> Self

Complex square root.

Uses the principal branch: sqrt(r) * (cos(theta/2) + i*sin(theta/2)).

pub fn pow(self, n: T) -> Self

Complex power: z^n = e^(n * ln(z)).

Examples
// (1+0i)^5 = 1
let z = Complex::new(1.0_f64, 0.0);
let p = z.pow(5.0_f64);
assert!((p.re - 1.0).abs() < 1e-10);
assert!(p.im.abs() < 1e-10);
pub fn is_finite(self) -> bool

Returns true if both real and imaginary parts are finite.

Examples
assert!(Complex::new(1.0_f64, 2.0).is_finite());
assert!(!Complex::new(f64::INFINITY, 0.0).is_finite());
pub fn is_nan(self) -> bool

Returns true if either part is NaN.

Examples
assert!(!Complex::new(1.0_f64, 2.0).is_nan());
assert!(Complex::new(f64::NAN, 0.0).is_nan());
Source

impl<T: Float> Complex<T>

pub fn i() -> Self

The imaginary unit i.

Examples
let i = Complex::<f64>::i();
assert_eq!(i.re, 0.0);
assert_eq!(i.im, 1.0);